.. -*- mode: rst -*-

|CircleCI|_ |Zenhub|_ 

.. |CircleCI| image:: https://circleci.com/gh/neuro-ml/edr-gp.svg?style=svg
.. _CircleCI: https://circleci.com/gh/neuro-ml/edr-gp

.. |Zenhub| image:: https://raw.githubusercontent.com/ZenHubIO/support/master/zenhub-badge.png
.. _Zenhub: https://zenhub.com

edr-gp
============

A library for sparse effective (functional) dimensionality reduction via Gaussian Processes
